@@ -1,3 +1,5 @@
+//! serve middleware
+
 mod dir;
 mod fs;
 
@@ -12,7 +14,7 @@ mod tests {
     use super::*;
 
     #[derive(Debug, Serialize, Deserialize)]
-    pub struct JwtClaims {
+    struct JwtClaims {
         user: String,
         exp: i64,
     }
@@ -29,15 +31,14 @@ mod tests {
         let service = Service::new(router);
 
         async fn access(service: &Service, accept: &str, url: &str) -> String {
-            let request = Request::from_hyper(
-                hyper::Request::builder()
-                    .method("GET")
-                    .header("accept", accept)
-                    .uri(url)
-                    .body(hyper::Body::empty())
-                    .unwrap(),
-            );
-            service.handle(request).await.take_text().await.unwrap()
+            let req: Request = hyper::Request::builder()
+                .method("GET")
+                .header("accept", accept)
+                .uri(url)
+                .body(hyper::Body::empty())
+                .unwrap()
+                .into();
+            service.handle(req).await.take_text().await.unwrap()
         }
         let content = access(&service, "text/plain", "http://127.0.0.1:7979/").await;
         assert!(content.contains("test1.txt") && content.contains("test2.txt"));
